autogen\_core
=============

.. automodule:: autogen_core
   :members:
   :undoc-members:
   :show-inheritance:
   :member-order: bysource

.. For some reason the following isn't picked up by automodule above
.. autoclass:: autogen_core.ComponentType